@@ -8,4 +8,7 @@ enableSemantics();
 {% for extension in extensions %}
 # {{ extension.name }}
 # {{ extension.url }}
-{{ extension.getLocalSettingsLine(mwShortVersion) }}{% endfor %}
\ No newline at end of file
+{{ extension.getLocalSettingsLine(mwShortVersion) }}{% endfor %}
+# modified defaults
+# https://www.mediawiki.org/wiki/Manual:$wgEnableUploads
+$wgEnableUploads = true;
\ No newline at end of file
